pub struct ExploitAbility {
pub attack_vector: AttackVectorType,
pub attack_complexity: AttackComplexityType,
pub privileges_required: PrivilegesRequiredType,
pub user_interaction: UserInteractionType,
}Expand description
2.1. Exploitability Metrics
As mentioned, the Exploitability metrics reflect the characteristics of the thing that is vulnerable, which we refer to formally as the vulnerable component. Therefore, each of the Exploitability metrics listed below should be scored relative to the vulnerable component, and reflect the properties of the vulnerability that lead to a successful attack.
Fields
attack_vector: AttackVectorTypeAttackVectorType 访问途径(AV)
attack_complexity: AttackComplexityTypeAttackComplexityType 攻击复杂度(AC)
privileges_required: PrivilegesRequiredTypePrivilegesRequiredType 所需权限(PR)
user_interaction: UserInteractionTypeUserInteractionType 用户交互(UI)
Implementations