pub enum AttackComplexityType {
High,
Low,
}Expand description
Attack Complexity (AC) 攻击复杂度
攻击复杂度为攻击者无法控制的条件,这些条件必须存在才能攻击脆弱组件。 如下文所述,这些条件可能需要预先收集有关目标或系统的配置或计算异常等更多信息。
The Attack Complexity metric describes the conditions beyond the attacker’s control that must exist in order to knowledge_base the vulnerability. As described below, such conditions may require the collection of more information about the target, the presence of certain system configuration settings, or computational exceptions.
Variants
Implementations
Sourceimpl AttackComplexityType
impl AttackComplexityType
pub fn metric_help(&self) -> Help