ExploitAbility

Struct ExploitAbility 

pub struct ExploitAbility {
    pub attack_vector: AttackVectorType,
    pub attack_complexity: AttackComplexityType,
    pub attack_requirements: AttackRequirementsType,
    pub privileges_required: PrivilegesRequiredType,
    pub user_interaction: UserInteractionType,
}
2.1. Exploitability Metrics

As mentioned, the Exploitability metrics reflect the characteristics of the thing that is vulnerable, which we refer to formally as the vulnerable component. Therefore, each of the Exploitability metrics listed below should be scored relative to the vulnerable component, and reflect the properties of the vulnerability that lead to a successful attack.

Fields

attack_vector: AttackVectorType

AttackVectorType 访问途径(AV)

attack_complexity: AttackComplexityType

AttackComplexityType 攻击复杂度(AC)

attack_requirements: AttackRequirementsType

AttackRequirementsType 攻击要求(AT)

privileges_required: PrivilegesRequiredType

PrivilegesRequiredType 所需权限(PR)

user_interaction: UserInteractionType

UserInteractionType 用户交互(UI)

Implementations

Source

impl ExploitAbility

pub fn score(&self) -> f32

8.22 × 𝐴𝑡𝑡𝑎𝑐𝑘𝑉𝑒𝑐𝑡𝑜𝑟 × 𝐴𝑡𝑡𝑎𝑐𝑘𝐶𝑜𝑚𝑝𝑙𝑒𝑥𝑖𝑡𝑦 × 𝑃𝑟𝑖𝑣𝑖𝑙𝑒𝑔𝑒𝑅𝑒𝑞𝑢𝑖𝑟𝑒𝑑 × 𝑈𝑠𝑒𝑟𝐼𝑛𝑡𝑒𝑟𝑎𝑐𝑡𝑖𝑜𝑛